@@ -41,7 +41,7 @@ def create_upload_dict(client:labelboxClient, table: pandas.core.frame.DataFrame
                        dataset_id_col:str, dataset_id:str,
                        project_id_col:str, project_id:str,
                        metadata_index:dict, attachment_index:dict, annotation_index:dict,
-                       divider:str, verbose:bool, extra_client:bool=None):
+                       upload_method:str, divider:str, verbose:bool, extra_client:bool=None):
     """
     Args:
         client                      :   Required (labelbox.client.Client) - Labelbox Client object        
@@ -57,6 +57,7 @@ def create_upload_dict(client:labelboxClient, table: pandas.core.frame.DataFrame
         metadata_index              :   Required (dict) - Dictonary where {key=metadata_field_name : value=metadata_type}
         attachment_index            :   Required (dict) - Dictonary where {key=column_name : value=attachment_type}
         annotation_index            :   Required (dict) - Dictonary where {key=column_name : value=top_level_feature_name}
+        upload_method               :   Required (str) - Either "mal" or "import" - required to upload annotations (otherwise leave as "")
         divider                     :   Required (str) - String delimiter for all name keys generated
         verbose                     :   Required (bool) - If True, prints details about code execution; if False, prints minimal information
         extra_client                :   Ignore this value - necessary for other labelbase integrations                
@@ -82,7 +83,7 @@ def create_upload_dict(client:labelboxClient, table: pandas.core.frame.DataFrame
     else:
         project_ids = []
     project_id_to_ontology_index = {}
-    if project_ids:
+    if (project_ids!=[]) and (atachment_index!={}) and (upload_method in ["mal", "import"]): # If we're uploading annotations
         for projectId in project_ids:
             ontology_index = labelbase.ontology.get_ontology_schema_to_name_path(
                 ontology=client.get_project(projectId).ontology(), 
@@ -100,7 +101,7 @@ def create_upload_dict(client:labelboxClient, table: pandas.core.frame.DataFrame
             futures.append(exc.submit(
                 create_upload, row_dict, row_data_col, global_key_col, external_id_col, dataset_id_col, dataset_id,
                 project_id_col, project_id, metadata_index, attachment_index, annotation_index, 
-                project_id_to_ontology_index, metadata_name_key_to_schema, divider, verbose 
+                project_id_to_ontology_index, metadata_name_key_to_schema, upload_method, divider, verbose 
             ))
         for f in as_completed(futures):
             res = f.result()
@@ -119,7 +120,7 @@ def create_upload(row_dict:dict,
                   project_id_col:str, project_id:str,
                   metadata_index:dict, attachment_index:dict, annotation_index:dict, 
                   project_id_to_ontology_index:dict, metadata_name_key_to_schema:dict,
-                  divider:str, verbose:bool):
+                  upload_method:str, divider:str, verbose:bool):
     """ Takes a row as-a-dictinary and returns a dictionary where:
     {
         "data_row" : {
@@ -136,7 +137,10 @@ def create_upload(row_dict:dict,
     """
     # Determine project ID and dataset ID
     datasetId = dataset_id if dataset_id else row_dict[dataset_id_col]
-    projectId = project_id if project_id else row_dict[project_id_col]
+    if project_id == project_id_col == "":
+        projectId = ""
+    else:
+        projectId = project_id if project_id else row_dict[project_id_col]
     # Create a base data row dictionary
     data_row = {
         "row_data" : row_dict[row_data_col],
@@ -163,7 +167,7 @@ def create_upload(row_dict:dict,
         data_row["attachments"] = [{"type" : attachment_index[column_name], "value" : row_dict[column_name]} for column_name in attachment_index]
     # Create a list of annotation ndjsons for a data row (does not include data row ID since data row has not been created)
     annotations = []        
-    if (annotation_index!={}) and (project_id_to_ontology_index!={}):
+    if (annotation_index!={}) and (project_id_to_ontology_index!={}) and (upload_method in ["mal", "import"]):
         ontology_index = project_id_to_ontology_index[projectId]
         for column_name in annotation_index.keys():
             annotations.extend(
